==> zio-aws-ec2_2.12-5.17.130.5-sources.jar: zio/aws/ec2/model/EnableEbsEncryptionByDefaultResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class EnableEbsEncryptionByDefaultResponse(
    ebsEncryptionByDefault: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableEbsEncryptionByDefaultResponse = {
    import EnableEbsEncryptionByDefaultResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableEbsEncryptionByDefaultResponse
      .builder()
      .optionallyWith(
        ebsEncryptionByDefault.map(value => value: java.lang.Boolean)
      )(_.ebsEncryptionByDefault)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse.ReadOnly =
    zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse.wrap(buildAwsValue())
}
object EnableEbsEncryptionByDefaultResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableEbsEncryptionByDefaultResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse =
      zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse(
        ebsEncryptionByDefault.map(value => value)
      )
    def ebsEncryptionByDefault: Option[Boolean]
    def getEbsEncryptionByDefault: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("ebsEncryptionByDefault", ebsEncryptionByDefault)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableEbsEncryptionByDefaultResponse
  ) extends zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse.ReadOnly {
    override val ebsEncryptionByDefault: Option[Boolean] =
      scala.Option(impl.ebsEncryptionByDefault()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableEbsEncryptionByDefaultResponse
  ): zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.194.1-sources.jar: zio/aws/ec2/model/EnableEbsEncryptionByDefaultResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EnableEbsEncryptionByDefaultResponse(
    ebsEncryptionByDefault: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableEbsEncryptionByDefaultResponse = {
    import EnableEbsEncryptionByDefaultResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableEbsEncryptionByDefaultResponse
      .builder()
      .optionallyWith(
        ebsEncryptionByDefault.map(value => value: java.lang.Boolean)
      )(_.ebsEncryptionByDefault)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse.ReadOnly =
    zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse.wrap(buildAwsValue())
}
object EnableEbsEncryptionByDefaultResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableEbsEncryptionByDefaultResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse =
      zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse(
        ebsEncryptionByDefault.map(value => value)
      )
    def ebsEncryptionByDefault: Optional[Boolean]
    def getEbsEncryptionByDefault: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("ebsEncryptionByDefault", ebsEncryptionByDefault)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableEbsEncryptionByDefaultResponse
  ) extends zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse.ReadOnly {
    override val ebsEncryptionByDefault: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ebsEncryptionByDefault())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableEbsEncryptionByDefaultResponse
  ): zio.aws.ec2.model.EnableEbsEncryptionByDefaultResponse.ReadOnly =
    new Wrapper(impl)
}
